@@ -37,9 +37,6 @@ class Core:
         self.parser = None
         self.subparsers = None
 
-        # store old state to avoid modification on the same object
-        self._previous_configs = Config._config_map.copy()
-
     def init_parser(self):
         self.parser = PdmParser(
             prog="pdm",
@@ -65,22 +62,26 @@ class Core:
                 klass = module.Command  # type: Type[BaseCommand]
             except AttributeError:
                 continue
-            self.register_command(klass, name)
+            self.register_command(klass, klass.name or name)
 
     def __call__(self, *args, **kwargs):
         return self.main(*args, **kwargs)
 
     def main(self, args=None, prog_name=None, obj=None, **extra):
         """The main entry function"""
-        Config._config_map = self._previous_configs.copy()
         self.init_parser()
         self.load_plugins()
 
+        self.parser.set_defaults(global_project=None)
         options = self.parser.parse_args(args or None)
         stream.set_verbosity(options.verbose)
 
+        if obj is not None:
+            options.project = obj
+        if options.global_project:
+            options.project = options.global_project
         if not getattr(options, "project", None):
-            options.project = obj or self.project_class()
+            options.project = self.project_class()
 
         # Add reverse reference for core object
         options.project.core = self
@@ -106,6 +107,7 @@ class Core:
         """Register a subcommand to the subparsers,
         with an optional name of the subcommand.
         """
+        command.project_class = self.project_class
         command.register_to(self.subparsers, name)
 
     @staticmethod
