@@ -2,6 +2,7 @@
 Compatibility code
 """
 import atexit
+import distutils.util
 import functools
 import importlib
 import inspect
@@ -489,3 +490,13 @@ def open_file(url, session=None):
                     if conn is not None:
                         conn.close()
                 result.close()
+
+
+def get_platform():
+    """Return our platform name 'win32', 'linux_x86_64'"""
+    # XXX remove distutils dependency
+    result = distutils.util.get_platform().replace(".", "_").replace("-", "_")
+    if result == "linux_x86_64" and sys.maxsize == 2147483647:
+        # pip pull request #3497
+        result = "linux_i686"
+    return result
